@@ -19,7 +19,7 @@
 #'
 #' @section Function version: 0.1.0
 #'
-#' @author Sebastian Kreutzer, IRAMAT-CRP2A, Universite Bordeaux Montaigne (France)
+#' @author Sebastian Kreutzer, Geography & Earth Sciences, Aberystwyth University (United Kingdom)
 #'
 #' @examples
 #'
@@ -60,7 +60,7 @@
 #'
 #' @section Function version: 0.1.0
 #'
-#' @author Sebastian Kreutzer, IRAMAT-CRP2A, Universite Bordeaux Montaigne (France)
+#' @author Sebastian Kreutzer, Geography & Earth Sciences, Aberystwyth University (United Kingdom)
 #'
 #' @examples
 #'
@@ -143,7 +143,7 @@
 #'
 #' @section Function version: 0.1.1
 #'
-#' @author Sebastian Kreutzer, IRAMAT-CRP2A, Universite Bordeaux Montaigne (France)
+#' @author Sebastian Kreutzer, Geography & Earth Sciences, Aberystwyth University (United Kingdom)
 #'
 #' @examples
 #'
@@ -249,7 +249,7 @@ fancy_scientific <- function(l) {
 #'
 #'@param suffix [character] (with default): allows to add a suffix to the entire string
 #'
-#'@author Sebastian Kreutzer, IRAMAT-CRP2A, Universite Bordeaux Montaigne (France)
+#'@author Sebastian Kreutzer, Geography & Earth Sciences, Aberystwyth University (United Kingdom)
 #'
 #'@section Version: 0.1.0
 #'
@@ -336,9 +336,9 @@ fancy_scientific <- function(l) {
 #'
 #' @param x [list] (**required**): list with lists
 #'
-#' @author Sebastian Kreutzer, IRAMAT-CRP2A, Université Bordeaux Montaigne (France)
+#' @author Sebastian Kreutzer, Geography & Earth Sciences, Aberystwyth University (United Kingdom)
 #'
-#' @example
+#' @examples
 #' a <- list(b = list(c = list("test")))
 #' .unlist_RLum(a)
 #'
@@ -383,7 +383,7 @@ fancy_scientific <- function(l) {
 #'
 #' @author Sebastian Kreutzer, IRAMAT-CRP2A, UMR 5060, CNRS - Université Bordeaux Montaigne (France)
 #'
-#' @section Function version: 0.1.1
+#' @section Function version: 0.1.2
 #'
 #' @note Row and column names are transformed to numeric and also summed up; this is not a bug
 #' but a feature!
@@ -407,7 +407,7 @@ fancy_scientific <- function(l) {
 
 
   # The only check ------------------------------------------------------------------------------
-  if(class(m) != "matrix")
+  if(class(m)[1] != "matrix")
     stop("[.matrix_binning()] Input is not of class 'matrix'!", call. = FALSE)
 
   # transpose in column mode --------------------------------------------------------------------
