@@ -174,7 +174,7 @@
 #' `..$call` : \tab `call` \tab The original function call\cr
 #' }
 #'
-#' @section Function version: 1.10.9
+#' @section Function version: 1.10.11
 #'
 #' @author
 #' Sebastian Kreutzer, IRAMAT-CRP2A, UMR 5060, CNRS - Université Bordeaux Montaigne (France)\cr
@@ -198,7 +198,11 @@
 #' temp <- plot_GrowthCurve(LxTxData)
 #' get_RLum(temp)
 #'
-#' ##(1a) to access the fitting value try
+#' ##(1b) horizontal plot arrangement
+#' layout(mat = matrix(c(1,1,2,3), ncol = 2))
+#' plot_GrowthCurve(LxTxData, output.plotExtended.single = TRUE)
+#'
+#' ##(1c) to access the fitting value try
 #' get_RLum(temp, data.object = "Fit")
 #'
 #' ##(2) plot the growth curve only - uncomment to use
@@ -1836,7 +1840,7 @@ plot_GrowthCurve <- function(
     extraArgs <- list(...)
 
     main <- if("main" %in% names(extraArgs)) {extraArgs$main} else
-    {"Growth curve"}
+    {"Dose-response curve"}
 
     xlab <- if("xlab" %in% names(extraArgs)) {extraArgs$xlab} else
     {"Dose [s]"}
@@ -1901,17 +1905,17 @@ plot_GrowthCurve <- function(
     x<-NULL; rm(x)
 
     #PAR	#open plot area
-    if(output.plot== TRUE &
-       output.plotExtended== TRUE &
-       output.plotExtended.single == FALSE ){
+    if(output.plot == TRUE &
+       output.plotExtended == TRUE &
+       output.plotExtended.single == FALSE){
 
       ####grep recent plot parameter for later reset
-      par.default.complex <- par(no.readonly = TRUE)
-      on.exit(par(par.default.complex))
+      par.default.complex <- par()["cex"]
+      on.exit(par(cex = par.default.complex$cex))
 
       ##set new parameter
-      layout(matrix(c(1,1,1,1,2,3), 3, 2, byrow=TRUE), respect=TRUE)
-      par(cex=0.8*cex.global)
+      layout(matrix(c(1, 1, 1, 1, 2, 3), 3, 2, byrow = TRUE), respect = TRUE)
+      par(cex = 0.8 * cex.global)
 
     }else{
 
@@ -1953,7 +1957,7 @@ plot_GrowthCurve <- function(
       }
 
       #ADD HEADER
-      title(main = main, line = 3)
+      title(main = main, line = NA)
 
       #CURVE	#plot fitted curve
       if (fit.method == "EXP+LIN") {
@@ -2074,7 +2078,7 @@ plot_GrowthCurve <- function(
       ##TEXT		#Insert fit and result
       try(mtext(side = 3,
                 mtext,
-                line = 0.5,
+                line = 0,
                 cex = 0.8 * cex.global), silent = TRUE)
 
       #write error message in plot if De is NaN
@@ -2139,7 +2143,7 @@ plot_GrowthCurve <- function(
             x.natural,
             xlab = xlab,
             ylab = "Frequency",
-            main = expression(paste(D[e], " from MC simulation")),
+            main = "MC runs",
             freq = FALSE,
             border = "white",
             axes = FALSE,
@@ -2235,7 +2239,7 @@ plot_GrowthCurve <- function(
               NA,
               xlim = c(0, 10),
               ylim = c(0, 10),
-              main = "Test dose response"
+              main = "Test-dose response"
             )
             text(5, 5, "not available\n no TnTx column")
           }#end if else
