@@ -9,7 +9,6 @@ test_that("Check the example and the numerical values", {
   ##get function and check whether we get NULL
   expect_null(get_Risoe.BINfileData(temp))
 
-
   ##check object
   expect_is(temp, class = "Risoe.BINfileData")
   expect_output(show(temp))
@@ -18,4 +17,7 @@ test_that("Check the example and the numerical values", {
   data(ExampleData.BINfileData, envir = environment())
   expect_output(show(CWOSL.SAR.Data))
 
+  ##as.data.frame
+  expect_s3_class(as.data.frame(CWOSL.SAR.Data), "data.frame")
+
 })
